@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.90';
+  $CPAN::Perl::Releases::VERSION = '0.92';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -335,6 +335,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.17.6.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.17.6.tar.gz",
   },
+  "5.17.7" => {
+    "tar.bz2" => "D/DR/DROLSKY/perl-5.17.7.tar.bz2",
+    "tar.gz" => "D/DR/DROLSKY/perl-5.17.7.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -443,7 +447,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.90
+version 0.92
 
 =head1 SYNOPSIS
 
